package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.CourseTable;

/**
 * 课程Service接口
 * 
 * @author ruoyi
 * @date 2023-05-24
 */
public interface ICourseTableService 
{
    /**
     * 查询课程
     * 
     * @param id 课程主键
     * @return 课程
     */
    public CourseTable selectCourseTableById(Long id);

    /**
     * 查询课程列表
     * 
     * @param courseTable 课程
     * @return 课程集合
     */
    public List<CourseTable> selectCourseTableList(CourseTable courseTable);

    /**
     * 新增课程
     * 
     * @param courseTable 课程
     * @return 结果
     */
    public int insertCourseTable(CourseTable courseTable);

    /**
     * 修改课程
     * 
     * @param courseTable 课程
     * @return 结果
     */
    public int updateCourseTable(CourseTable courseTable);

    /**
     * 批量删除课程
     * 
     * @param ids 需要删除的课程主键集合
     * @return 结果
     */
    public int deleteCourseTableByIds(Long[] ids);

    /**
     * 删除课程信息
     * 
     * @param id 课程主键
     * @return 结果
     */
    public int deleteCourseTableById(Long id);

    AjaxResult now(Long schoolId,Long classId);
}
